# ymir command line interface

## Features

* Manage your images, annotations using mir command line

* Training detection models

* Mining datas with trained detection models

## Requirements

* Linux

* Docker

## Installation

To install ymir command line tools, run:

```
pip install ymir-cmd
```

## Tutorals

See `tutoral/domo-cycle.sh`
